@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import math
 from abc import abstractmethod, ABC
 from enum import IntEnum
 from typing import List, Optional
@@ -726,7 +727,7 @@ def construct_git(
         creature.position.y = creature_struct.acquire("YPosition", 0.0)
         creature.position.z = creature_struct.acquire("ZPosition", 0.0)
         rot_x, rot_y = creature_struct.acquire("XOrientation", 0.0), creature_struct.acquire("YOrientation", 0.0)
-        creature.bearing = Vector2(rot_x, rot_y).angle()
+        creature.bearing = Vector2(rot_x, rot_y).angle() - math.pi/2
 
     for door_struct in gff.root.get_list("Door List"):
         door = GITDoor()
@@ -802,7 +803,7 @@ def construct_git(
         store.position.z = store_struct.acquire("ZPosition", 0.0)
 
         rot_x, rot_y = store_struct.acquire("XOrientation", 0.0), store_struct.acquire("YOrientation", 0.0)
-        store.bearing = Vector2(rot_x, rot_y).angle()
+        store.bearing = Vector2(rot_x, rot_y).angle() - math.pi/2
 
     for trigger_struct in gff.root.get_list("TriggerList"):
         trigger = GITTrigger()
@@ -841,7 +842,7 @@ def construct_git(
             waypoint.map_note_enabled = waypoint_struct.acquire("MapNoteEnabled", 0)
 
         rot_x, rot_y = waypoint_struct.acquire("XOrientation", 0.0), waypoint_struct.acquire("YOrientation", 0.0)
-        waypoint.bearing = Vector2(rot_x, rot_y).angle()
+        waypoint.bearing = Vector2(rot_x, rot_y).angle() - math.pi/2
 
     return git
 
